# ValorantInstalocker
Simple Open-Source __UNDETECTED__ Valorant instalocker.

# Installation

## From Binaries

Head over the [release tab](https://github.com/KamiHateOmg/ValorantInstalocker/releases/tag/1.0.0.0) and download the first and only release.

## From PIP

Enter these commands in a command prompt :
```bash
pip install instalocker
```
and when you want to use it :
```bash
instalocker
```

## From Source

Open a cmd in a folder and copy paste these commands : 
```bash
git clone https://github.com/KamiHateOmg/ValorantInstalocker.git Instalocker
```
```bash
cd Instalocker
```
```bash
pip install valclient
```
```bash
python lockerbykami.py
```

If you want to compile by yourself copy paste these commands : 
```bash
pip install pyinstaller
```
```bash
soon...
```

# Contact

```py
discord = by.kami
discord id = 1195405120398180494
```